AlignColumn

Struct AlignColumn 

pub struct AlignColumn<T: Token, D: TeXDimen> {
    pub left: Box<[T]>,
    pub right: Box<[T]>,
    pub inbraces: u8,
    pub tabskip: Skip<D>,
}
Specification on a column in an \halign (or a row in a \valign); in particular:

  • the alignment template for the column (or row)
  • the tabskip to be inserted between the columns (or rows),
  • the number of braces to inserted at the beginning of the column (or row).

The latter is important for the Gullet to know when an AlignmentTab Token (or a \cr) should be passed on or replaced by the relevant template tokens

Fields

left: Box<[T]>

The tokens to be inserted at the beginning of the column (or row)

right: Box<[T]>

The tokens to be inserted at the end of the column (or row)

inbraces: u8

The number of braces that are opened by the template tokens

tabskip: Skip<D>

The tabskip to be inserted between the columns (or rows)

Implementations

Source

impl<T: Token, D: TeXDimen> AlignColumn<T, D>

pub fn new(left: Vec<T>, right: Vec<T>, tabskip: Skip<D>, inbraces: u8) -> Self

Create a new AlignColumn with the given template tokens, tabskip and number of braces