AlignData

Struct AlignData 

pub struct AlignData<T: Token, D: TeXDimen> {
    pub token: T,
    pub ingroups: u8,
    pub currindex: usize,
    pub repeat_index: Option<usize>,
    pub columns: Box<[AlignColumn<T, D>]>,
    pub omit: bool,
    pub span: bool,
    pub inner_mode: BoxType,
    pub outer_mode: BoxType,
}
Data structure for a currently open \halign (or \valign)

Fields

token: Tingroups: u8

The number of braces that are currently open

currindex: usize

The index of the current column (or row)

repeat_index: Option<usize>

The index of the column (or row) to be repeated, if the number of columns (or rows) in a particular row exceeds the number of columns (or rows) in the template

columns: Box<[AlignColumn<T, D>]>

The columns (or rows) of the template

omit: bool

Whether the current column (or row) should omit the template

span: bool

Whether the current column (or row) spans across the next column (or rows)

inner_mode: BoxType

The mode of the current column (or row); this is either BoxType::Horizontal for an \halign or BoxType::Vertical for a \valign

outer_mode: BoxType

The mode between rows (or columns); this is either BoxType::Vertical for an \halign or BoxType::Horizontal for a \valign

Implementations

Source

impl<T: Token, D: TeXDimen> AlignData<T, D>

pub fn groupval(&self) -> u8

the number of open braces at which an AlignmentTab Token (or a \cr) should cause the template tokens to be inserted into the input stream

pub fn check_token(&mut self, t: &T) -> Option<bool>

pub fn dummy() -> Self

A dummy AlignData that makes sure that AlignmentTab Tokens (and \crs) are not replaced by a template; can be pushed to the Gullet at the begin of an \halign (or \valign) before the template is fully processed to avoid already open AlignDatas to be used.

pub fn on_alignment_tab<ET: EngineTypes<Token = T, Dim = D>>( &self, mouth: &mut ET::Mouth, aux: &mut EngineAux<ET>, ) -> T

Push the end-template tokens of the current column (or row) to the Mouth; this is called when an AlignmentTab Token (or a \span) is encountered and the number of currently open braces matches the current column’s inbraces value.

pub fn on_cr<ET: EngineTypes<Token = T, Dim = D>>( &self, mouth: &mut ET::Mouth, aux: &mut EngineAux<ET>, state: &ET::State, ) -> T

Push the end-template tokens of the current column (or row) to the Mouth and insert \everycr; this is called when a \cr or \crcr is encountered and the number of currently open braces matches the current column’s inbraces value.